==> hyperbahn-2.11.3.tgz: package/endpoints/circuits.js <==
// Copyright (c) 2015 Uber Technologies, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

'use strict';

module.exports = circuitsEndpoint;

function circuitsEndpoint(opts, req, head, body, cb) {
    var circuits = opts.clients.serviceProxy.circuits;

    var response = [];

    var circuitTuples = circuits ? circuits.getCircuitTuples() : [];
    for (var index = 0; index < circuitTuples.length; index++) {
        var circuitTuple = circuitTuples[index];
        var circuit = circuits.getCircuit.apply(circuits, circuitTuple);
        var state = circuit.state.type;
        response.push({
            cn: circuit.callerName,
            sn: circuit.serviceName,
            en: circuit.endpointName,
            healthy: state === 'tchannel.healthy' || state === 'tchannel.healthy-locked',
            locked: state === 'tchannel.healthy-locked' || state === 'tchannel.unhealthy-locked'
        });
    }

    cb(null, {
        ok: true,
        head: null,
        body: response
    });
}

==> hyperbahn-2.14.16.tgz: package/endpoints/circuits.js <==
// Copyright (c) 2015 Uber Technologies, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

'use strict';

module.exports = circuitsEndpoint;

function circuitsEndpoint(opts, req, head, body, cb) {
    var circuits = opts.clients.serviceProxy.circuits;

    var response = [];

    var circuitTuples = circuits ? circuits.getCircuitTuples() : [];
    for (var index = 0; index < circuitTuples.length; index++) {
        var circuitTuple = circuitTuples[index];
        var circuit = circuits.getCircuit.apply(circuits, circuitTuple);
        var state = circuit.state.type;
        response.push({
            cn: circuit.callerName,
            sn: circuit.serviceName,
            en: circuit.endpointName,
            healthy: state === 'tchannel.healthy'
        });
    }

    cb(null, {
        ok: true,
        head: null,
        body: response
    });
}
